|
From: <sv...@va...> - 2016-11-23 13:26:29
|
Author: sewardj
Date: Wed Nov 23 13:26:23 2016
New Revision: 16153
Log:
Bug 348616 - Wine/valgrind: Warning: noted but unhandled ioctl 0x5390
with no size/direction hints. (DVD_READ_STRUCT)
Patch from Austin English (aus...@gm...).
Modified:
trunk/coregrind/m_syswrap/syswrap-linux.c
trunk/include/vki/vki-linux.h
Modified: trunk/coregrind/m_syswrap/syswrap-linux.c
==============================================================================
--- trunk/include/vki/vki-linux.h (original)
+++ trunk/include/vki/vki-linux.h Wed Nov 23 13:26:23 2016
@@ -1885,6 +1885,7 @@
#define VKI_CDROM_DISC_STATUS 0x5327 /* get CD type information */
#define VKI_CDROM_GET_CAPABILITY 0x5331 /* get capabilities */
+#define VKI_DVD_READ_STRUCT 0x5390 /* read structure */
#define VKI_CDROM_SEND_PACKET 0x5393 /* send a packet to the drive */
struct vki_cdrom_msf0
|
--- trunk/coregrind/m_syswrap/syswrap-linux.c (original)
+++ trunk/coregrind/m_syswrap/syswrap-linux.c Wed Nov 23 13:26:23 2016
@@ -5674,7 +5674,10 @@
case VKI_CDROM_DISC_STATUS:
case VKI_CDROMSTOP:
- /* KVM ioctls that dont check for a numeric value as parameter */
+ /* DVD stuff */
+ case VKI_DVD_READ_STRUCT:
+
+ /* KVM ioctls that don't check for a numeric value as parameter */
case VKI_KVM_S390_ENABLE_SIE:
case VKI_KVM_CREATE_IRQCHIP:
case VKI_KVM_S390_INITIAL_RESET:
@@ -9226,6 +9229,10 @@
case VKI_CDROM_GET_CAPABILITY: /* 0x5331 */
break;
+ /* DVD stuff */
+ case VKI_DVD_READ_STRUCT:
+ break;
+
case VKI_FIGETBSZ:
POST_MEM_WRITE(ARG3, sizeof(unsigned long));
break;
Modified: trunk/include/vki/vki-linux.h
==============================================================================